@@ -6,7 +6,7 @@
 #
 
 package File::ByLine;
-$File::ByLine::VERSION = '1.181962'; # TRIAL
+$File::ByLine::VERSION = '1.181980'; # TRIAL
 use v5.10;
 
 # ABSTRACT: Line-by-line file access loops
@@ -162,7 +162,7 @@ File::ByLine - Line-by-line file access loops
 
 =head1 VERSION
 
-version 1.181962
+version 1.181980
 
 =head1 SYNOPSIS
 
@@ -494,9 +494,10 @@ Constructs a new object, suitable for the object oriented calls below.
 
 =head3 extended_info
 
+  $extended = $byline->extended_info();
   $byline->extended_info(1);
 
-This was added in 1.181951.
+This was added in version 1.181951.
 
 Gets and sets the "extended information" flag.  This defaults to false, but
 if set to a true value this will pass a second parameter to all user-defined
@@ -522,7 +523,7 @@ should be modified within user code.
 
 =head3 file
 
-  my $current_file = $byline->file();
+  my $file = $byline->file();
   $byline->file("abc.txt");
   $byline->file( [ "abc.txt", "def.txt" ] );
   $byline->file( "$abc.txt", "def.txt" );
@@ -538,6 +539,7 @@ file.
 
 =head3 header_all_files
 
+  my $all_files = $byline->header_all_files();
   $byline->header_all_files(1);
 
 Gets and sets whether the object oriented methods will call C<header_handler>
@@ -551,6 +553,7 @@ headers of all files may be read at once before any data line is read.
 
 =head3 header_handler
 
+  my $handler = $byline->header_handler();
   $byline->header_handler( sub { ... } );
 
 Specifies code that should be executed on the header row of the input file.
@@ -580,6 +583,32 @@ process.  Specifying C<2> or greater will use multiple processes to operate
 on the file (see documentation for the parallel_* functions described above
 for more details).
 
+=head3 skip_unreadable
+
+  my $unreadable = $byline->skip_unreadable();
+  $byline->skip_unreadable(10);
+
+This was added in version 1.181980.
+
+If this attribute is true, unreadable files are treated as empty files during
+processing.  The default is false, in which case an exception is thrown when
+an access attempt is made to an unreadable file.
+
+=head3 Short Name Aliases for Attributes
+
+  $byline->f();     # Alias for file
+  $byline->ei();    # Alias for extended_info
+  $byline->haf();   # Alias for header_all_files
+  $byline->hh();    # Alias for header_handler
+  $byline->hs();    # Alias for header_skip
+  $byline->p();     # Alias for processes
+  $byline->su();    # Alias for skip_unreadable
+
+Short name aliases were added in version 1.181980.
+
+Each attribute listed above has a corresponding short name.  This short name
+can also be used as a constructor argument.
+
 =head2 METHODS
 
 =head3 do
