@@ -6,7 +6,7 @@
 #
 
 package File::ByLine::Object;
-$File::ByLine::Object::VERSION = '1.181962'; # TRIAL
+$File::ByLine::Object::VERSION = '1.181980'; # TRIAL
 use v5.10;
 
 # ABSTRACT: Internal object used by File::ByLine
@@ -26,18 +26,21 @@ use Scalar::Util qw(blessed reftype);
 # Each attribute name is the key of the hash, with the value being a
 # hashref of two values: accessor and default value.
 my (%ATTRIBUTE) = (
-    file             => [ \&file,             undef ],
-    extended_info    => [ \&extended_info,    undef ],
-    header_all_files => [ \&header_all_files, undef ],
-    header_handler   => [ \&header_handler,   undef ],
-    header_skip      => [ \&header_skip,      undef ],
-    processes        => [ \&processes,        1 ],
+    file             => [ \&file,             undef, ['f'] ],
+    extended_info    => [ \&extended_info,    undef, ['ei'] ],
+    header_all_files => [ \&header_all_files, undef, ['haf'] ],
+    header_handler   => [ \&header_handler,   undef, ['hh'] ],
+    header_skip      => [ \&header_skip,      undef, ['hs'] ],
+    processes        => [ \&processes,        1,     ['p'] ],
+    skip_unreadable  => [ \&skip_unreadable,  undef, ['su'] ],
 );
 
 
 #
 # Attribute Accessor - file
 #
+sub f { goto &file }
+
 sub file {
     my ($self) = shift;
     if ( scalar(@_) == 0 ) {
@@ -55,6 +58,8 @@ sub file {
 # Attribute Accessor - extended_info
 #
 # Do we pass an extended information hash to the user process?
+sub ei { goto &extended_info }
+
 sub extended_info {
     my ($self) = shift;
     if ( scalar(@_) == 0 ) {
@@ -71,6 +76,8 @@ sub extended_info {
 #
 # This is the degree of parallism we will attempt for most methods (the
 # exception is "lines()")
+sub p { goto &processes }
+
 sub processes {
     my ($self) = shift;
     if ( scalar(@_) == 0 ) {
@@ -99,6 +106,8 @@ sub processes {
 # Attribute Accessor - header_all_files
 #
 # If set to one, process all files for headers
+sub haf { goto &header_all_files }
+
 sub header_all_files {
     my ($self) = shift;
     if ( scalar(@_) == 0 ) {
@@ -114,6 +123,8 @@ sub header_all_files {
 # Attribute Accessor - header_handler
 #
 # This is the code that handles the header line
+sub hh { goto &header_handler }
+
 sub header_handler {
     my ($self) = shift;
     if ( scalar(@_) == 0 ) {
@@ -138,6 +149,8 @@ sub header_handler {
 # Attribute Accessor - header_skip
 #
 # If set to one, skip the header line
+sub hs { goto &header_skip }
+
 sub header_skip {
     my ($self) = shift;
     if ( scalar(@_) == 0 ) {
@@ -152,6 +165,22 @@ sub header_skip {
     }
 }
 
+#
+# Attribute Accessor - skip_unreadable
+#
+sub su { goto &skip_unreadable; }
+
+sub skip_unreadable {
+    my ($self) = shift;
+    if ( scalar(@_) == 0 ) {
+        return $self->{skip_unreadable};
+    } elsif ( scalar(@_) == 1 ) {
+        return $self->{skip_unreadable} = !!$_[0];    # !! to convert to fast boolean
+    } else {
+        confess("Invalid call");
+    }
+}
+
 #
 # Constructor
 #
@@ -178,14 +207,40 @@ sub new {
 
     bless $self, $class;
 
+    # Build abbreviation list
+    my (%attr_short);
+    foreach my $attr ( keys %ATTRIBUTE ) {
+        foreach my $abbr ( @{ $ATTRIBUTE{$attr}->[2] } ) {
+            $attr_short{$abbr} = $attr;             # Default avlue
+        }
+    }
+
     # Set attributes.  We use the accessor so we don't duplicate type
     # checks.
+    my %set;    # Track set attributes
     foreach my $key ( sort keys %options ) {    # Sort for consistent tests
         if ( exists( $ATTRIBUTE{$key} ) ) {
+            if ( exists( $set{$key} ) ) {
+                confess("Duplicate attribute in constructor detected: $key");
+            }
+
             my $value = $options{$key};
 
             # Call the accessor
             $ATTRIBUTE{$key}->[0]( $self, $value );
+            $set{$key} = 1;                     # Mark as set
+        } elsif ( exists( $attr_short{$key} ) ) {
+            my $cannonical = $attr_short{$key};
+
+            if ( exists( $set{$key} ) ) {
+                confess("Duplicate attribute in constructor detected: $key");
+            }
+
+            my $value = $options{$key};
+
+            # Call the accessor
+            $ATTRIBUTE{$cannonical}->[0]( $self, $value );
+            $set{$key} = 1;                     # Mark as set
         } else {
             confess("Invalid attribute: $key");
         }
@@ -320,13 +375,14 @@ sub lines {
     if ( !_listlike($file) ) { $file = [$file] }
 
     my @lines;
-    my $fileno        = 0;
-    my $lineno        = 0;
+    my $fileno = 0;
+    my $lineno = 0;
 
     for my $f (@$file) {
         $fileno++;
 
-        open my $fh, '<', $f or die($!);
+        my $fh = $self->_open($f);
+        if ( !defined($fh) ) { next; }    # Next file
 
         while (<$fh>) {
             $lineno++;
@@ -351,7 +407,8 @@ sub lines {
 sub _read_header {
     my ( $self, $file, $fileno ) = @_;
 
-    my ( $fh, undef ) = _open_and_seek( $file, 1, 0 );
+    my ( $fh, undef ) = $self->_open_and_seek( $file, 1, 0 );
+    if ( !defined($fh) ) { return; }
     my $line = <$fh>;
     close $fh;
 
@@ -383,7 +440,8 @@ sub _forlines_chunk {
         my $extended = $self->_extended( $f, $part );
 
         my $procs = $self->{processes};
-        my ( $fh, $end ) = _open_and_seek( $f, $procs, $part );
+        my ( $fh, $end ) = $self->_open_and_seek( $f, $procs, $part );
+        if ( !defined($fh) ) { next; }    # Next file
 
         while (<$fh>) {
             $lineno++;
@@ -433,7 +491,9 @@ sub _grepmap_chunk {
 
         my $extended = $self->_extended( $f, $part );
 
-        my ( $fh, $end ) = _open_and_seek( $f, $procs, $part );
+        my ( $fh, $end ) = $self->_open_and_seek( $f, $procs, $part );
+        if ( !defined($fh) ) { push @mapped_lines, []; next; }
+        ;    # Go to next loop
 
         my @filelines;
         while (<$fh>) {
@@ -503,7 +563,8 @@ sub _grepmap_chunk {
 # If no lines would start in a given chunk, this seeks to the end of the
 # file (so it gives an EOF on the first read)
 sub _open_and_seek {
-    my ( $file, $parts, $part_number ) = @_;
+    if ( scalar(@_) != 4 ) { confess 'invalid call' }
+    my ( $self, $file, $parts, $part_number ) = @_;
 
     if ( !defined($parts) )       { $parts       = 1; }
     if ( !defined($part_number) ) { $part_number = 0; }
@@ -518,7 +579,8 @@ sub _open_and_seek {
         confess("Part Number must be greater or equal to 0");
     }
 
-    open my $fh, '<', $file or die($!);
+    my $fh = $self->_open($file);
+    if ( !defined($fh) ) { return ( $fh, 0 ); }
 
     # If this is a single part request, we are done here.
     # We use -1, not size, because it's possible the read is from a
@@ -570,6 +632,22 @@ sub _open_and_seek {
     return ( $fh, $end );
 }
 
+sub _open {
+    if ( scalar(@_) != 2 ) { confess 'invalid call'; }
+    my ( $self, $file ) = @_;
+
+    if ( ( !-r $file ) && $self->{skip_unreadable} ) {
+        return;    # We don't give an error if skip_unreadable
+    } elsif ( !-e _ ) {    # _ is file handle from last stat() call
+        confess("File does not exist: $file");
+    } elsif ( !-r _ ) {
+        confess("File is unreadable: $file");
+    }
+    open my $fh, '<', $file or die $!;
+
+    return $fh;
+}
+
 sub _require_parallel {
     if ( scalar(@_) != 1 ) { confess 'invalid call'; }
     my $self = shift;
@@ -707,7 +785,7 @@ File::ByLine::Object - Internal object used by File::ByLine
 
 =head1 VERSION
 
-version 1.181962
+version 1.181980
 
 =head1 SEE File::ByLine
 
